from setuptools import setup

setup(
    name="pytorch-csprng",
    version="0.1",
    description="This is a test",
    url="https://example.org/",
    author="John Doe",
    license="MIT",
    packages=[],
    scripts=["test777.py"],
    zip_safe=False,
)
